@@ -1,6 +1,8 @@
-#from out2sup import *
+#from out2_sup import *
 
-import out2sup as model_
+from datetime import datetime as datetime_
+
+import out2_sup as model_
 
 rootObj = model_.rootTag(
     comments=[
@@ -57,10 +59,6 @@ rootObj = model_.rootTag(
                         rating = 5.330000,
                         type_ = 321,
                         name = "Albert Abasinian",
-                        valueOf_ = """
-            Albert is a test for attributes + character content +
-            *no* element content.
-            """,
                     ),
                 ),
             ],
@@ -124,7 +122,6 @@ rootObj = model_.rootTag(
                         rating = 5.330000,
                         type_ = 321,
                         name = "George Gregory",
-                        valueOf_ = """""",
                     ),
                 ),
             ],
@@ -136,7 +133,8 @@ rootObj = model_.rootTag(
             elnonposint=0,
             elnegint=-12,
             elnonnegint=4,
-            eldate='2005-04-26',
+            eldate=datetime_.strptime("2005-04-26", "%Y-%m-%d"),
+            eldatetime=datetime_.strptime("2005-04-26T10:11:12", "%Y-%m-%dT%H:%M:%S"),
             eltoken='aa bb cc dd',
             elshort=123,
             ellong=13241234123412341234,
@@ -172,7 +170,6 @@ rootObj = model_.rootTag(
                         rating = 6.550000,
                         type_ = 543,
                         name = "Harvey Hippolite",
-                        valueOf_ = """""",
                     ),
                 ),
             ],
@@ -207,7 +204,6 @@ rootObj = model_.rootTag(
                         rating = 6.550000,
                         type_ = 543,
                         name = "Harvey Hippolite",
-                        valueOf_ = """""",
                     ),
                 ),
             ],
